This function ranks items in the data based on either the Relative Importance Index (RII) or the mean of responses.
rank_items(data, method = "rii", max_scale = 5, n = 5, top = TRUE)A vector of ranked items.
A data.frame of ordinal items.
Method to rank items. Either "rii" (for Relative Importance Index) or "mean" (for mean response).
Max Likert scale value (default: 5).
Number of top items to return (default: 5).
Logical. If TRUE, returns the top items, otherwise returns the bottom items (default: TRUE).